==> haskell-hspec-core-2.8.1-8-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hspec-core
version:              2.8.1
visibility:           public
id:                   hspec-core-2.8.1-6QSPJrODOrRC2Pc4h1wFWs
key:                  hspec-core-2.8.1-6QSPJrODOrRC2Pc4h1wFWs
license:              MIT
copyright:
    (c) 2011-2021 Simon Hengel,
    (c) 2011-2012 Trystan Spangler,
    (c) 2011 Greg Weber

maintainer:           Simon Hengel <sol@typeful.net>
stability:            experimental
homepage:             http://hspec.github.io/
synopsis:             A Testing Framework for Haskell
description:
    This package exposes internal types and functions that can be used to extend Hspec'\''s functionality.

category:             Testing
abi:                  e3dcc6e0f9114b3d8e928966087051eb
exposed:              True
exposed-modules:
    Test.Hspec.Core.Format Test.Hspec.Core.Formatters
    Test.Hspec.Core.Formatters.V1 Test.Hspec.Core.Formatters.V2
    Test.Hspec.Core.Hooks Test.Hspec.Core.QuickCheck
    Test.Hspec.Core.Runner Test.Hspec.Core.Spec Test.Hspec.Core.Util

hidden-modules:
    Test.Hspec.Core.Clock Test.Hspec.Core.Compat Test.Hspec.Core.Config
    Test.Hspec.Core.Config.Options Test.Hspec.Core.Config.Util
    Test.Hspec.Core.Example Test.Hspec.Core.Example.Location
    Test.Hspec.Core.FailureReport Test.Hspec.Core.Formatters.Diff
    Test.Hspec.Core.Formatters.Free Test.Hspec.Core.Formatters.Internal
    Test.Hspec.Core.Formatters.Monad Test.Hspec.Core.QuickCheckUtil
    Test.Hspec.Core.Runner.Eval
    Test.Hspec.Core.Runner.PrintSlowSpecItems Test.Hspec.Core.Shuffle
    Test.Hspec.Core.Spec.Monad Test.Hspec.Core.Timer
    Test.Hspec.Core.Tree Control.Concurrent.Async Data.Algorithm.Diff
    Paths_hspec_core

import-dirs:          /usr/lib/ghc-8.10.4/site-local/hspec-core-2.8.1
library-dirs:         /usr/lib/ghc-8.10.4/site-local/hspec-core-2.8.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/hspec-core-2.8.1
hs-libraries:         HShspec-core-2.8.1-6QSPJrODOrRC2Pc4h1wFWs
depends:
    HUnit-1.6.2.0-6Qz5k8URKehKv59h9ZmD3M
    QuickCheck-2.14.2-1Bekdcpaoco52kkbfPlodE
    ansi-terminal-0.11-6nluG5txe6B9NiOiR32C01 array-0.5.4.0
    base-4.14.1.0 call-stack-0.3.0-5Mj0U3oidh8Dm8auDPZCpq
    clock-0.8.2-9UFKXEvaIlvHBGUfGAYdEd deepseq-1.4.4.0
    directory-1.3.6.0 filepath-1.4.2.1
    hspec-expectations-0.8.2-4T2sv1DBBhWKyVScectlCn
    quickcheck-io-0.2.0-4gU6vWlrzMS1SypvfcEXGP
    random-1.2.0-5H7ZZJPy96IF0kgiy7zIEA
    setenv-0.1.1.3-FjFLzlxhySgkTKHvS1WwL stm-2.5.0.0
    tf-random-0.5-7VatpAWu2Wp8VaULWsxlQ0 transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-hspec-core/html/hspec-core.haddock
haddock-html:         /usr/share/doc/haskell-hspec-core/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-core-2.8.2-6-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hspec-core
version:              2.8.2
visibility:           public
id:                   hspec-core-2.8.2-7sSgwoOfonqBEko12UawtI
key:                  hspec-core-2.8.2-7sSgwoOfonqBEko12UawtI
license:              MIT
copyright:
    (c) 2011-2021 Simon Hengel,
    (c) 2011-2012 Trystan Spangler,
    (c) 2011 Greg Weber

maintainer:           Simon Hengel <sol@typeful.net>
stability:            experimental
homepage:             http://hspec.github.io/
synopsis:             A Testing Framework for Haskell
description:
    This package exposes internal types and functions that can be used to extend Hspec'\''s functionality.

category:             Testing
abi:                  2dd330f9fd28a415c36e22a1c9e03734
exposed:              True
exposed-modules:
    Test.Hspec.Core.Format Test.Hspec.Core.Formatters
    Test.Hspec.Core.Formatters.V1 Test.Hspec.Core.Formatters.V2
    Test.Hspec.Core.Hooks Test.Hspec.Core.QuickCheck
    Test.Hspec.Core.Runner Test.Hspec.Core.Spec Test.Hspec.Core.Util

hidden-modules:
    Test.Hspec.Core.Clock Test.Hspec.Core.Compat Test.Hspec.Core.Config
    Test.Hspec.Core.Config.Options Test.Hspec.Core.Config.Util
    Test.Hspec.Core.Example Test.Hspec.Core.Example.Location
    Test.Hspec.Core.FailureReport Test.Hspec.Core.Formatters.Diff
    Test.Hspec.Core.Formatters.Free Test.Hspec.Core.Formatters.Internal
    Test.Hspec.Core.Formatters.Monad Test.Hspec.Core.QuickCheckUtil
    Test.Hspec.Core.Runner.Eval
    Test.Hspec.Core.Runner.PrintSlowSpecItems Test.Hspec.Core.Shuffle
    Test.Hspec.Core.Spec.Monad Test.Hspec.Core.Timer
    Test.Hspec.Core.Tree Control.Concurrent.Async Data.Algorithm.Diff
    Paths_hspec_core

import-dirs:          /usr/lib/ghc-8.10.4/site-local/hspec-core-2.8.2
library-dirs:         /usr/lib/ghc-8.10.4/site-local/hspec-core-2.8.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/hspec-core-2.8.2
hs-libraries:         HShspec-core-2.8.2-7sSgwoOfonqBEko12UawtI
depends:
    HUnit-1.6.2.0-6Qz5k8URKehKv59h9ZmD3M
    QuickCheck-2.14.2-JBdTpAobWwg19WOWKtgrIg
    ansi-terminal-0.11-B33URfqMvdcAXWIdsUyVZE array-0.5.4.0
    base-4.14.1.0 call-stack-0.3.0-5Mj0U3oidh8Dm8auDPZCpq
    clock-0.8.2-IFvGRANmnw26ROrpUllWNV deepseq-1.4.4.0
    directory-1.3.6.0 filepath-1.4.2.1
    hspec-expectations-0.8.2-4T2sv1DBBhWKyVScectlCn
    quickcheck-io-0.2.0-9HrQVSmVivAJ7G9GID2GdB
    random-1.2.0-IgxPFWwCjnD1SXfjtysFzY
    setenv-0.1.1.3-FjFLzlxhySgkTKHvS1WwL stm-2.5.0.0
    tf-random-0.5-7Nsw9LSLPxDTDvw3tuCsY transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-hspec-core/html/hspec-core.haddock
haddock-html:         /usr/share/doc/haskell-hspec-core/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
